//
// cocos2d Hello World example
// http://www.cocos2d-iphone.org
//

// Import the interfaces
#import "HelloWorldScene.h"

static int
floorCollision(cpShape *a, cpShape *b, cpContact *contacts, int numContacts, cpFloat normal_coef, void *data)
{
	HelloWorldScene *scene = (HelloWorldScene*)[[Director sharedDirector] runningScene];
	[scene floorCollision];
	return 1;
}

// HelloWorld implementation
@implementation HelloWorldScene

// on "init" you need to initialize your instance
-(id) init
{
	// always call "super" init
	// Apple recommends to re-assign "self" with the "super" return value
	if( (self=[super init] )) {
		
		points = 0;
		
		// create and initialize a Label
		label = [Label labelWithString:@"0" fontName:@"Marker Felt" fontSize:20];
		[label setPosition:ccp(40, 450)];
		[label setColor:ccc3(255,255,0)];
		[self addChild:label z:0];
		
		// create an animation
		AtlasSpriteManager *mgr = [AtlasSpriteManager spriteManagerWithFile:@"seta_verde.png" capacity:8];
		seta = [AtlasSprite spriteWithRect:CGRectMake(0, 0, 45, 40) spriteManager:mgr];
		AtlasAnimation *anim = [AtlasAnimation animationWithName:@"anim1" delay:0.05f];
		for (int i=0; i<8; i++) {
			[anim addFrameWithRect:CGRectMake(i*45, 0, 45, 40)];
		}
		[seta setPosition:ccp(250,48)];
		[seta setOpacity:0];
		[mgr addChild:seta];
		[self addChild:mgr z:1];
		id action = [RepeatForever actionWithAction:
						[Animate actionWithAnimation:anim]];
		[seta runAction:action];
		id action2 = [RepeatForever actionWithAction:
					  [Sequence actions:
					  [MoveBy actionWithDuration:0.25f position:ccp(-15,0)],
					  [MoveBy actionWithDuration:0.25f position:ccp(15,0)],
					  nil]];
		[mgr runAction:action2];
		
		
		// loading ball image
		ball = [Sprite spriteWithFile:@"ball.png"];
		[ball setPosition:ccp(160, 300)];
		[self addChild:ball z:3];
		
		// initializing chipmunk
		cpInitChipmunk();
		space = cpSpaceNew();
		space->gravity = cpv(0, -500);
		space->elasticIterations = 1;
		// creating ball's body
		ball_body = cpBodyNew(60.0, 50000.0);
		ball_body->p = cpv(ball.position.x, ball.position.y);
		cpSpaceAddBody(space, ball_body);
		// creating ball's shape (for collisions)
		ball_shape = cpCircleShapeNew(ball_body, 48, cpvzero);
		ball_shape->e = 1.0f;
		ball_shape->u = 0.8f;
		ball_shape->data = ball;
		ball_shape->collision_type = 1;
		cpSpaceAddShape(space, ball_shape);
		// creating floor
		cpBody* floorBody = cpBodyNew(INFINITY, INFINITY);
		floorBody->p = cpv(0, 0);
		cpVect verts[] = { 
			cpv(-100, -90), 
			cpv(-100, 0), 
			cpv(420, 0), 
			cpv(420, -90) 
		};
		cpShape* shape = cpPolyShapeNew(floorBody, 4, verts, cpvzero);
		shape->e = 0.3f; shape->u = 0.8f;
		shape->collision_type = 2;
		cpSpaceAddStaticShape(space, shape);
		
		[self schedule:@selector(updateChipmunk:) interval:1.0f/60];
		
		cpSpaceAddCollisionPairFunc(space, 1, 2, &floorCollision, NULL);
		
		[[TouchDispatcher sharedDispatcher] addStandardDelegate:self priority:1];
	}
	return self;
}

- (void) floorCollision{
	if([seta opacity]==0) [seta setOpacity:255];
	if(points>0){
		server = [ScoreServerPost serverWithGameName:@"TutorialCocos2d" gameKey:@"xxxxxx" delegate:self];
		NSMutableDictionary *dict = [NSMutableDictionary new];
		[dict setObject:[NSNumber numberWithInt:points] forKey:@"cc_score"];
		[dict setObject:@"Fulano" forKey:@"cc_playername"];
		[dict setObject:@"Classic" forKey:@"cc_category"];
		[server sendScore:dict];
		points = 0;
	}
}

- (void) scorePostOk: (id) sender{
	
}

- (void) scorePostFail: (id) sender{
	
}


- (void) updateChipmunk:(ccTime) dt{
	cpSpaceStep(space, dt);
	[ball setPosition:ccp(ball_body->p.x, ball_body->p.y)];
}

- (BOOL)ccTouchesBegan:(NSSet *)touches withEvent:(UIEvent *)event{
	
	UITouch *touch = [touches anyObject];
	CGPoint location = [touch locationInView: [touch view]];
	location = [[Director sharedDirector] convertToGL:location];
	
	float dx = ball.position.x - location.x;
	float dy = ball.position.y - location.y;
	float dist = sqrt((dx*dx + dy*dy));
	
	if(dist<48){
		//NSLog(@"Dentro da bola");
		cpBodyApplyImpulse(ball_body, cpv(0,20000), cpvzero);
		[seta setOpacity:0];
		points++;
		[label setString:[NSString stringWithFormat:@"%d", points]];
	}
	
	return kEventHandled;
}

// on "dealloc" you need to release all your retained objects
- (void) dealloc
{
	// in case you have something to dealloc, do it in this method
	// in this particular example nothing needs to be released.
	// cocos2d will automatically release all the children (Label)
	
	// don't forget to call "super dealloc"
	[super dealloc];
}
@end
